@@ -59,6 +59,9 @@ int omap_enable_layer(int enabled)
 	return 0;
 }
 
+static void caanoo_init(void);
+
+
 static void *fb_flip(void)
 {
 	memregl[0x406C>>2] = memregl[0x446C>>2] = fb_paddrs[fb_work_buf];
@@ -586,6 +589,11 @@ void plat_init(void)
 		in_gp2x_init();
 	}
 
+	in_tsbutton_init();
+	in_probe();
+	if (gp2x_dev_id == GP2X_DEV_CAANOO)
+		caanoo_init();
+
 	mixerdev = open("/dev/mixer", O_RDWR);
 	if (mixerdev == -1)
 		perror("open(/dev/mixer)");
@@ -598,8 +606,6 @@ void plat_init(void)
 	psx_width = 320;
 	psx_height = 240;
 	psx_bpp = 16;
-
-	in_tsbutton_init();
 }
 
 void plat_finish(void)
@@ -623,10 +629,6 @@ void plat_finish(void)
 	close(memdev);
 }
 
-void in_update_analogs(void)
-{
-}
-
 /* Caanoo stuff, perhaps move later */
 #include <linux/input.h>
 
@@ -666,6 +668,97 @@ static const char * const caanoo_keys[KEY_MAX + 1] = {
 	[BTN_BASE5]     = "Push",
 };
 
+struct haptic_data {
+	int count;
+	struct {
+		short time, strength;
+	} actions[120];
+};
+
+#define HAPTIC_IOCTL_MAGIC	'I'
+#define HAPTIC_PLAY_PATTERN	_IOW(HAPTIC_IOCTL_MAGIC, 4, struct haptic_data)
+#define HAPTIC_INDIVIDUAL_MODE	_IOW(HAPTIC_IOCTL_MAGIC, 5, unsigned int)
+#define HAPTIC_SET_VIB_LEVEL	_IOW(HAPTIC_IOCTL_MAGIC, 9, unsigned int)
+
+static int hapticdev = -1;
+static struct haptic_data haptic_seq;
+
+static int haptic_init(void)
+{
+	int i, ret, v1, v2;
+	char buf[128], *p;
+	FILE *f;
+
+	f = fopen("haptic.txt", "r");
+	if (f == NULL) {
+		perror("fopen(haptic.txt)");
+		return -1;
+	}
+
+	for (i = 0; i < sizeof(haptic_seq.actions) / sizeof(haptic_seq.actions[0]); ) {
+		p = fgets(buf, sizeof(buf), f);
+		if (p == NULL)
+			break;
+		while (*p != 0 && *p == ' ')
+			p++;
+		if (*p == 0 || *p == ';' || *p == '#')
+			continue;
+
+		ret = sscanf(buf, "%d %d", &v1, &v2);
+		if (ret != 2) {
+			fprintf(stderr, "can't parse: %s", buf);
+			continue;
+		}
+
+		haptic_seq.actions[i].time = v1;
+		haptic_seq.actions[i].strength = v2;
+		i++;
+	}
+	fclose(f);
+
+	if (i == 0) {
+		fprintf(stderr, "bad haptic.txt\n");
+		return -1;
+	}
+	haptic_seq.count = i;
+
+	hapticdev = open("/dev/isa1200", O_RDWR | O_NONBLOCK);
+	if (hapticdev == -1) {
+		perror("open(/dev/isa1200)");
+		return -1;
+	}
+
+	i = 0;
+	ret  = ioctl(hapticdev, HAPTIC_INDIVIDUAL_MODE, &i);	/* use 2 of them */
+	i = 3;
+	ret |= ioctl(hapticdev, HAPTIC_SET_VIB_LEVEL, &i);	/* max */
+	if (ret != 0) {
+		fprintf(stderr, "haptic ioctls failed\n");
+		close(hapticdev);
+		hapticdev = -1;
+		return -1;
+	}
+
+	return 0;
+}
+
+void plat_trigger_vibrate(void)
+{
+	int ret;
+
+	if (hapticdev == -2)
+		return; // it's broken
+	if (hapticdev < 0) {
+		ret = haptic_init();
+		if (ret < 0) {
+			hapticdev = -2;
+			return;
+		}
+	}
+
+	ioctl(hapticdev, HAPTIC_PLAY_PATTERN, &haptic_seq);
+}
+
 /* Wiz stuff */
 struct in_default_bind in_gp2x_defbinds[] =
 {
@@ -714,12 +807,8 @@ void plat_step_volume(int is_up)
 // unused dummy for in_gp2x
 volatile unsigned short *gp2x_memregs;
 
-int plat_rescan_inputs(void)
+static void caanoo_init(void)
 {
-	in_probe();
-	if (gp2x_dev_id == GP2X_DEV_CAANOO)
-		in_set_config(in_name_to_id("evdev:pollux-analog"), IN_CFG_KEY_NAMES,
-			      caanoo_keys, sizeof(caanoo_keys));
-
-	return 0;
+	in_set_config(in_name_to_id("evdev:pollux-analog"), IN_CFG_KEY_NAMES,
+		      caanoo_keys, sizeof(caanoo_keys));
 }
