@@ -16,6 +16,12 @@
 #define PCSX 1
 #define RAM_SIZE 0x200000
 
+#ifndef __ARM_ARCH_7A__
+#define ARMv5_ONLY
+//#undef CORTEX_A8_BRANCH_PREDICTION_HACK
+//#undef USE_MINI_HT
+#endif
+
 #ifdef FORCE32
 #define REG_SHIFT 2
 #else
