@@ -676,8 +676,10 @@ long CALLBACK GPUopen(int hwndGPU)
 // lGPUstatusRet = 0x74000000;
 
 // with some emus, we could do the OGL init right here... oh my
-// if(bIsFirstFrame) GLinitialize();
+ if(bIsFirstFrame) GLinitialize();
 
+extern Display*                x11Display ;
+hwndGPU=x11Display;
  return 0;
 }
 
